[llvm] r217514 - Fix comments of createReplaceableForwardDecl() and createForwardDecl().

Frederic Riss friss at apple.com
Wed Sep 10 09:03:15 PDT 2014


Author: friss
Date: Wed Sep 10 11:03:14 2014
New Revision: 217514

URL: http://llvm.org/viewvc/llvm-project?rev=217514&view=rev
Log:
Fix comments of createReplaceableForwardDecl() and createForwardDecl().

Noticed while trying to understand how the merge of forward decalred types
and defintions work.

Reviewers: echristo, dblaikie, aprantl

Subscribers: llvm-commits

Differential Revision: http://reviews.llvm.org/D5291

Modified:
    llvm/trunk/lib/IR/DIBuilder.cpp

Modified: llvm/trunk/lib/IR/DIBuilder.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/IR/DIBuilder.cpp?rev=217514&r1=217513&r2=217514&view=diff
==============================================================================
--- llvm/trunk/lib/IR/DIBuilder.cpp (original)
+++ llvm/trunk/lib/IR/DIBuilder.cpp Wed Sep 10 11:03:14 2014
@@ -879,8 +879,7 @@ DIBasicType DIBuilder::createUnspecified
   return DIBasicType();
 }
 
-/// createForwardDecl - Create a temporary forward-declared type that
-/// can be RAUW'd if the full type is seen.
+/// createForwardDecl - Create a permanent forward-declared type.
 DICompositeType
 DIBuilder::createForwardDecl(unsigned Tag, StringRef Name, DIDescriptor Scope,
                              DIFile F, unsigned Line, unsigned RuntimeLang,
@@ -914,7 +913,7 @@ DIBuilder::createForwardDecl(unsigned Ta
   return RetTy;
 }
 
 /// createForwardDecl - Create a temporary forward-declared type that
 /// can be RAUW'd if the full type is seen.
 DICompositeType DIBuilder::createReplaceableForwardDecl(
     unsigned Tag, StringRef Name, DIDescriptor Scope, DIFile F, unsigned Line,
@@ -942,7 +941,7 @@ DICompositeType DIBuilder::createReplace
   MDNode *Node = MDNode::getTemporary(VMContext, Elts);
   DICompositeType RetTy(Node);
   assert(RetTy.isCompositeType() &&
-         "createForwardDecl result should be a DIType");
+         "createReplaceableForwardDecl result should be a DIType");
   if (!UniqueIdentifier.empty())
     retainType(RetTy);
   return RetTy;
@@ -914,7 +913,7 @@ DIBuilder::createForwardDecl(unsigned Ta
 }
 
-/// createForwardDecl - Create a temporary forward-declared type that
+/// createReplaceableForwardDecl - Create a temporary forward-declared type that
 /// can be RAUW'd if the full type is seen.
 DICompositeType DIBuilder::createReplaceableForwardDecl(





More information about the llvm-commits mailing list